# Maintainers

This document lists the Maintainers of the project.
Maintainers may be added once approved by the existing maintainers as described in the `../GOVERNANCE.md` document.
By adding your name to this list you are agreeing to abide by the governance documents and to abide by all of the Organization's polices, including the code of conduct, trademark policy, and antitrust policy.
If you are participating because of your affiliation with another organization (designated below), you represent that you have the authority to bind that organization to these policies.

<!-- EXAMPLE: The current contents of the table are given for an example, please update. -->

| **Lastname** | **Name** | **Handle** | **ORCID** | **Affiliation** | **Role** |
| --- | --- | --- | --- | --- | --- |
| Markiewicz | Christopher J. | @effigies | 0000-0002-6533-164X | Department of Psychology, Stanford University, CA, USA | |
| Goncalves | Mathias | @mgxd | 0000-0002-7252-7771 | Department of Psychology, Stanford University, CA, USA | |
| Esteban | Oscar | @oesteban | 0000-0001-8435-6191 | Lausanne University Hospital and University of Lausanne, Lausanne, Switzerland | |
| Pinsard | Basile | @bpinsard | 0000-0002-4391-3075 | Université de Montréal, Montreal, QC, CA | 20.2.x LTS maintainer |
